@@ -24,6 +24,8 @@ class eSpeakCallerDaemon():
         self.logger = logging.getLogger('eSpeakCaller')
         self.contacts = espeakcaller_contacts.Contacts()
         self.incomingnumber = ""
+        self.eSpeakProc = 0
+        self.silenceSpeakers = 0
         
         bus = dbus.SystemBus()
         sbus = dbus.SessionBus()
